///////////////////////////////////////////////////////////////////////////////
//
// Copyright 1999-2003 National Instruments Corporation.  All Rights Reserved.
//
///////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////
//
// File:
//
//    Debug.h
//
// Purpose:
//
//    This file defines Debug functions used.
//
// Modifications Required:
//
//
//////////////////////////////////////////////////////////////////////////////

// Ensure that this header file is included only once per compilation unit.
#if !defined ___debug_h___
#define      ___debug_h___


//////////////////////////////////////////////////////////////////////////////
//
// Serial functions - used to send debugging messges through serial
//
//////////////////////////////////////////////////////////////////////////////

void VISASerialInit		(void);
void VISAPrintToSerial	(const char * pFormat, ...); 
void VISASerialClose	(void);


//////////////////////////////////////////////////////////////////////////////
//
// Print Function
//
//////////////////////////////////////////////////////////////////////////////

#define PrintF(message) VISAPrintToSerial message;

//////////////////////////////////////////////////////////////////////////////
//
// Debugging Macros
//
//////////////////////////////////////////////////////////////////////////////

// Only define these debugging macros during debug builds.
#if defined(_DEBUG)

   #define DebugOnly(x) x

   #define PrintToDebugger(message) PrintF (message);

   #define Assert(test)                    \
   {                                         \
      if (!(test))                           \
      {                                      \
         PrintF ((                          \
            "OSAssert (%s)\n"                \
            "  File '%s' line %d\n",         \
            #test,                           \
            __FILE__,                        \
            __LINE__                         \
            ));                               \
      }                                      \
   }

   #define AssertWithMessage(test,message) \
   {                                         \
      if (!(test))                           \
      {                                      \
         PrintF ((                          \
            "Assert (%s)\n"                \
            "  File '%s' line %d\n"          \
            "%s\n",                          \
            #test,                           \
            __FILE__,                        \
            __LINE__,                        \
            message                          \
            ));                               \
      }                                      \
   }

    #define InitDebugging() VISASerialInit()
    #define CloseDebugging() VISASerialClose()

#else

   // Just define these as empty and they will be compiled out
   #define DebugOnly(x)
   #define PrintToDebugger(message)
   #define Assert(test)
   #define AssertWithMessage(test,message)

   #define InitDebugging() 
   #define CloseDebugging()
     
#endif

#endif // #if !defined ___osdebug_h___
